@@ -15,7 +15,7 @@ NetworkDevice::NetworkDevice(const QString &id, const QString &name)
     m_networkSensor->setShortName(i18nc("@title Short of Network Name", "Name"));
     m_networkSensor->setPrefix(name);
 
-    m_signalSensor = new KSysGuard::SensorProperty(QStringLiteral("signal"), i18nc("@title", "Signal Strength"), this);
+    m_signalSensor = new KSysGuard::SensorProperty(QStringLiteral("signal"), i18nc("@title", "Signal Strength"), 0, this);
     m_signalSensor->setShortName(i18nc("@title Short of Signal Strength", "Signal"));
     m_signalSensor->setUnit(KSysGuard::UnitPercent);
     m_signalSensor->setMin(0);
@@ -30,22 +30,22 @@ NetworkDevice::NetworkDevice(const QString &id, const QString &name)
     m_ipv6Sensor->setShortName(i18nc("@title Short of IPv6 Address", "IPv6"));
     m_ipv6Sensor->setPrefix(name);
 
-    m_downloadSensor = new KSysGuard::SensorProperty(QStringLiteral("download"), i18nc("@title", "Download Rate"), this);
+    m_downloadSensor = new KSysGuard::SensorProperty(QStringLiteral("download"), i18nc("@title", "Download Rate"), 0, this);
     m_downloadSensor->setShortName(i18nc("@title Short for Download Rate", "Download"));
     m_downloadSensor->setUnit(KSysGuard::UnitByteRate);
     m_downloadSensor->setPrefix(name);
 
-    m_uploadSensor = new KSysGuard::SensorProperty(QStringLiteral("upload"), i18nc("@title", "Upload Rate"), this);
+    m_uploadSensor = new KSysGuard::SensorProperty(QStringLiteral("upload"), i18nc("@title", "Upload Rate"), 0, this);
     m_uploadSensor->setShortName(i18nc("@title Short for Upload Rate", "Upload"));
     m_uploadSensor->setUnit(KSysGuard::UnitByteRate);
     m_uploadSensor->setPrefix(name);
 
-    m_downloadBitsSensor = new KSysGuard::SensorProperty(QStringLiteral("downloadBits"), i18nc("@title", "Download Rate"), this);
+    m_downloadBitsSensor = new KSysGuard::SensorProperty(QStringLiteral("downloadBits"), i18nc("@title", "Download Rate"), 0, this);
     m_downloadBitsSensor->setShortName(i18nc("@title Short for Download Rate", "Download"));
     m_downloadBitsSensor->setUnit(KSysGuard::UnitBitRate);
     m_downloadBitsSensor->setPrefix(name);
 
-    m_uploadBitsSensor = new KSysGuard::SensorProperty(QStringLiteral("uploadBits"), i18nc("@title", "Upload Rate"), this);
+    m_uploadBitsSensor = new KSysGuard::SensorProperty(QStringLiteral("uploadBits"), i18nc("@title", "Upload Rate"), 0, this);
     m_uploadBitsSensor->setShortName(i18nc("@title Short for Upload Rate", "Upload"));
     m_uploadBitsSensor->setUnit(KSysGuard::UnitBitRate);
     m_uploadBitsSensor->setPrefix(name);
